Module docs

Documentation for proc-macros and guides.

Modules

enums
structural supports enums. Structural enum traits can be both statically and dynamically dispatched.
structural_macro
The Structural derive macro implements the Structural trait, as well as accessor traits.