Module enums

Enum related traits and types.

The *VariantField* traits are declared in the field module, you can use *VariantField* traits as bounds, and then call StructuralExt methods to access fields inside enum variants.

Structs

VariantProxy
Enum wrapper,for accessing the fields of a particular variant (determined by the V type parameter).

Traits

EnumExt
Extension trait for enums.
IsVariant
Queries whether an enum is some variant (the V type parameter)
VariantCount
For querying the amount of variants of an enum.

Type Aliases

VariantCountOut
Queries the amount of variants of This.