Module ownership

Module ownership 

Items for moving out fields out of a type,and dropping it afterwards.

Structs

FieldBit
Represents the index for a field in MovedOutFields.
IntoFieldsWrapper
Helper type for moving fields out of a Structural type.
MovedOutFields
Which fields have been moved out of a value.
RunDrop
A guard that drops the value that a mutable reference points when it is dropped.
RunDropFields
A guard that calls DropFields::drop_fields on the mutable reference when it is dropped.
RunPostDrop
A guard that calls PrePostDropFields::post_drop on the mutable reference when it is dropped.

Traits

DropFields
Defines how the type is dropped, after some fields were moved out with the IntoField::move_out_field_ or IntoVariantField::move_out_vfield_ methods.
PrePostDropFields
For use in macros, to add code that runs before before and after the macro-generated DropFields::drop_fields code.