pub struct MovedOutFields(/* private fields */);Expand description
Which fields have been moved out of a value.
This is used to implement converting a value into multiple fields by value.
Example
This is a toy example,
for more realistic examples,you can look
at
the manual implementation example of IntoField
,or
the manual implementation example of IntoVariantField
.
use structural::field::{MovedOutFields, FieldBit};
// This is how `FieldBit` is constructed in the derive macro.
const FIELD_A_BIT: FieldBit= FieldBit::new(0);
const FIELD_B_BIT: FieldBit= FieldBit::new(1);
let mut moved = MovedOutFields::new();
// A `MovedOutFields` considers no field moved when constructed.
assert!( !moved.is_moved_out(FIELD_A_BIT) );
assert!( !moved.is_moved_out(FIELD_B_BIT) );
// `set_moved_out` is called in the
// `IntoField::move_out_field_`/`IntoVariantField::move_out_vfield_` implementation.
moved.set_moved_out(FIELD_A_BIT);
moved.set_moved_out(FIELD_B_BIT);
// `is_moved_out` is called in the `DropFields::drop_fields` implementation,
//
// If `is_moved_out` returns false, then a field has not been moved out,
// and must be dropped.
assert!( moved.is_moved_out(FIELD_A_BIT) );
assert!( moved.is_moved_out(FIELD_B_BIT) );
Implementations
Sourceimpl MovedOutFields
impl MovedOutFields
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Constructs a MovedOutFields where no field is considered moved out yet.
Sourcepub fn set_moved_out(&mut self, bit: FieldBit)
pub fn set_moved_out(&mut self, bit: FieldBit)
Marks a field as being moved out.
Sourcepub const fn is_moved_out(&self, bit: FieldBit) -> bool
pub const fn is_moved_out(&self, bit: FieldBit) -> bool
Checks whether a field has been moved out.