RunDrop

Struct RunDrop 

pub struct RunDrop<'a, T> { /* private fields */ }
A guard that drops the value that a mutable reference points when it is dropped.

Implementations

Source

impl<'a, T> RunDrop<'a, T>

pub unsafe fn new(mutref: &'a mut T) -> Self

Constructs this RunDrop.

Safety

In the destructor for this type, this drops the value that the mutable reference points to.

Once the destructor for this type runs,the pointed-to value must not be used again, that includes the destructor for the value running.

Drop order

Remember that variables on the stack are dropped in the opposite order than they are declared.

In this example:

let a=Foo;
let b=Bar;
let c=Baz;

c gets dropped first,then b, then a.

pub unsafe fn get_mut(&mut self) -> &mut T

Reborrows the wrapped mutable reference.

Safety

The returned references must not be mutated, only passed to accessor trait (declared in structural) methods for moving out fields .