[−][src]Macro structural::z_raw_borrow_enum_field
For creating a raw pointer of an enum field,as either Some(NonNull<_>) or None.
Safety
The $pointer must be raw pointer to a valid(and fully initialized)
instance of the $enum type.
Example
For an example of using this macro look at
the manual implementation example for GetVariantFieldMut