IsMultiFieldPath

Trait IsMultiFieldPath 

pub trait IsMultiFieldPath: Sized {
    type PathUniqueness;
}
A marker trait for field paths that refer to multiple fields

Expectations

This type is expected to implement RevGetMultiField.

Required Associated Types

type PathUniqueness

Whether the paths in the set can contain duplicate paths.

This is expected to be either:

  • structural::path::AliasedPaths: for a field path that might refer to the same field multiple times.

  • structural::path::UniquePaths: for a field path that doesn’t refer to a field more than once.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors