[−][src]Module structural::structural_aliases
Structural aliases for standard library types.
Array Traits
This module re-exports these traits from arrays_traits,with:
-
The
Array*structural aliases to use any type with accessors from 0 until the size of the array,in which all the field types are the same, -
The
Array*Variantstructural aliases to use any enum variant with accessors from 0 until the size of the array,in which all the field types are the same.
Tuple Traits
This module re-exports these traits from tuple_traits,with:
-
The
Tuple*structural aliases to use any type with accessors fromTS!(0)until the size of the tuple,in which all field types can be different, -
The
Tuple*Variantstructural aliases to use any enum variant with accessors fromTS!(0)until the size of the tuple,in which all field types can be different.
Re-exports
pub use self::array_traits::*; |
pub use self::tuple_traits::*; |
Modules
| array_traits | Traits (including structural aliases) for arrays. |
| tuple_traits | Contains structural aliases for tuples, with shared,mutable,and by value access to every field of the tuple. |
Traits
| OptionMove_ESI | Structural alias for |
| OptionMove_SI | Structural alias for |
| Option_SI | Structural alias for |
| RangeFrom_SI | Structural alias for |
| RangeRef_SI | Structural alias for |
| RangeTo_SI | Structural alias for |
| Range_SI | Structural alias for |
| ResultMove_ESI | Structural alias for |
| ResultMove_SI | Structural alias for |
| Result_ESI | Structural alias for |
| Result_SI | Structural alias for |