pub trait Array2<T>: IntoFieldMut<I0, Ty = T> + IntoFieldMut<I1, Ty = T> { }Expand description
A structural alias for an array of this size. With shared,mutable,and by value access to the elements.
pub trait Array2<T>: IntoFieldMut<I0, Ty = T> + IntoFieldMut<I1, Ty = T> { }A structural alias for an array of this size. With shared,mutable,and by value access to the elements.