Trait ArrayMove0

pub trait ArrayMove0<T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Implementors

Source

impl<This, T> ArrayMove0<T> for This
where This: ?Sized,