Trait ArrayMove19

pub trait ArrayMove19<T>:
    ArrayMove_8_16<T>
    + IntoField<I16, Ty = T>
    + IntoField<I17, Ty = T>
    + IntoField<I18, Ty = T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Implementors

Source

impl<This, T> ArrayMove19<T> for This
where This: ?Sized + ArrayMove_8_16<T> + IntoField<I16, Ty = T> + IntoField<I17, Ty = T> + IntoField<I18, Ty = T>,