ArrayMove2

Trait ArrayMove2 

pub trait ArrayMove2<T>: IntoField<I0, Ty = T> + IntoField<I1, Ty = T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<This, T> ArrayMove2<T> for This
where This: ?Sized + IntoField<I0, Ty = T> + IntoField<I1, Ty = T>,