ArrayMove21

Trait ArrayMove21 

pub trait ArrayMove21<T>:
    ArrayMove_8_16<T>
    + IntoField<I16, Ty = T>
    + IntoField<I17, Ty = T>
    + IntoField<I18, Ty = T>
    + IntoField<I19, Ty = T>
    + IntoField<I20, Ty = T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<This, T> ArrayMove21<T> for This
where This: ?Sized + ArrayMove_8_16<T> + IntoField<I16, Ty = T> + IntoField<I17, Ty = T> + IntoField<I18, Ty = T> + IntoField<I19, Ty = T> + IntoField<I20, Ty = T>,