Trait ArrayMove24

pub trait ArrayMove24<T>: ArrayMove_16_24<T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Implementors

Source

impl<This, T> ArrayMove24<T> for This
where This: ?Sized + ArrayMove_16_24<T>,