ArrayMove25

Trait ArrayMove25 

pub trait ArrayMove25<T>: ArrayMove_16_24<T> + IntoField<I24, Ty = T> { }
A structural alias for an array of this size. With shared and by value access to the elements.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<This, T> ArrayMove25<T> for This
where This: ?Sized + ArrayMove_16_24<T> + IntoField<I24, Ty = T>,