Tuple2Variant

Trait Tuple2Variant 

pub trait Tuple2Variant<C0, C1, V>: IntoVariantFieldMut<V, I0, Ty = C0> + IntoVariantFieldMut<V, I1, Ty = C1> { }
A structural alias for a tuple variant of the size, in which all fields have mutable and by-value accessors.

The last type parameter takes the name of the variant as a TStr

Implementors

Source

impl<C0, C1, This, V> Tuple2Variant<C0, C1, V> for This
where This: IntoVariantFieldMut<V, I0, Ty = C0> + IntoVariantFieldMut<V, I1, Ty = C1>,