pub trait Tuple3Variant<C0, C1, C2, V>:
IntoVariantFieldMut<V, I0, Ty = C0>
+ IntoVariantFieldMut<V, I1, Ty = C1>
+ IntoVariantFieldMut<V, I2, Ty = C2> { }Expand description
A structural alias for a tuple variant of the size, in which all fields have mutable and by-value accessors.
The last type parameter takes the name of the variant as a TStr
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".