[][src]Module structural::structural_trait

Contains the Structural trait with info about the fields that have accessor trait impls.

Structs

FieldInfo

Information about a field with accessor trait impls.

Traits

Structural

Indicates and provides information about the fields that implement accessor traits.

StructuralDyn

An object-safe version of the Structural trait. with information about the fields that implement accessor traits.

Functions

accessor_names

An iterator over the name parameters for T's accessor trait impls,

field_names

The names of T's fields that have accessor trait impls.