Documentation for proc-macros and guides.
Modules
- enums
structuralsupports enums. Structural enum traits can be both statically and dynamically dispatched.- structural_
macro - The Structural derive macro implements the Structural trait, as well as accessor traits.