[−][src]Module structural::docs
Documentation for proc-macros and guides.
Modules
| structural_macro | The Structural derive macro implements the Structural trait, as well as accessor traits(GetField/GetFieldMut/IntoField) for fields. |
Documentation for proc-macros and guides.
| structural_macro | The Structural derive macro implements the Structural trait, as well as accessor traits(GetField/GetFieldMut/IntoField) for fields. |