Items for moving out fields out of a type,and dropping it afterwards.
Structs
- Field
Bit - Represents the index for a field in
MovedOutFields. - Into
Fields Wrapper - Helper type for moving fields out of a Structural type.
- Moved
OutFields - Which fields have been moved out of a value.
- RunDrop
- A guard that drops the value that a mutable reference points when it is dropped.
- RunDrop
Fields - A guard that calls
DropFields::drop_fieldson the mutable reference when it is dropped. - RunPost
Drop - A guard that calls
PrePostDropFields::post_dropon the mutable reference when it is dropped.
Traits
- Drop
Fields - Defines how the type is dropped,
after some fields were moved out
with the
IntoField::move_out_field_orIntoVariantField::move_out_vfield_methods. - PrePost
Drop Fields - For use in macros,
to add code that runs before before and after the macro-generated
DropFields::drop_fieldscode.