pub struct RunDrop<'a, T> { /* private fields */ }Expand description
A guard that drops the value that a mutable reference points when it is dropped.
Implementations
Sourceimpl<'a, T> RunDrop<'a, T>
impl<'a, T> RunDrop<'a, T>
Sourcepub unsafe fn new(mutref: &'a mut T) -> Self
pub unsafe fn new(mutref: &'a mut T) -> Self
Constructs this RunDrop.
Safety
In the destructor for this type, this drops the value that the mutable reference points to.
Once the destructor for this type runs,the pointed-to value must not be used again, that includes the destructor for the value running.
Drop order
Remember that variables on the stack are dropped in the opposite order than they are declared.
In this example:
ⓘ
let a=Foo;
let b=Bar;
let c=Baz;c gets dropped first,then b, then a.