[−][src]Struct structural::TStr
Type-level string,used for identifiers in field paths.
This type is always zero sized.
This cannot be converted to a &'static str constant
(if you can figure out a cheap way to do that please create an issue/pull request).
Semver concerns
The private __TS type appears as a type argument of TStr
in the output of macros from this crate,
the __TS type must not be used by name outside of the structural and structural_derive
crates.
Direct use of the __TS type will cause compilation errors
whenever any other crate uses the "use_const_str" cargo feature,
which changes __TS to use const generics to improve error messages.
TStr type
You can get a TStr type (to use as a type argument) with the TS macro,
which takes a string literal/ident/integer as input.
TStr construction
TStr<_> can be constructed with:
-
the
tsmacro,which takes a string literal/ident/integer as input. -
the
fpmacro,when a single string literal/ident/integer in passed, prefer usingtsif you want aTStrto always be constructed, sincefpcan produce other types depending on the arguments. -
the
NEWinherent associated constant. -
The
<TStr<_> as ConstDefault>::DEFAULTassociated constant.
Examples:
-
ts!(foo): TStr equivalent of "foo" -
ts!("bar"): TStr equivalent of "bar" -
ts!(1): TStr equivalent of "1" -
ts!(100): TStr equivalent of "100" -
fp!(foo): TStr equivalent of "foo" -
fp!("bar"): TStr equivalent of "bar" -
fp!("@me"): TStr equivalent of "@me" -
fp!(100): TStr equivalent of "100" -
<TS!(0)>::NEW: TStr equivalent of "0" -
<TS!(0)>::DEFAULT: TStr equivalent of "0" (requires importing theConstDefaulttrait) -
<TS!("hello")>::NEW: TStr equivalent of "hello" -
<TS!(world)>::NEW: TStr equivalent of "world" -
<TS!(100)>::NEW: TStr equivalent of "100"
Example
For an example of constructing TStr using the ts macro,
and constructing other field paths with it,
you can look in the docs for the ts macro.
Methods
impl<T> TStr<T>[src]
impl<T> TStr<T>[src]
pub const fn into_path(self) -> NestedFieldPath<(Self,)>[src]
Constructs a NestedFieldPath from this.
pub const fn into_set(self) -> FieldPathSet<(Self,), UniquePaths>[src]
Constructs a FieldPathSet from this.